# Programmation de la Boitearire
La Boitearire fonctionne grâce à un micro-contrôleur qui analyse les movements et actions perçu par des capteurs électronique. Il est nécessaire de le programmer afin qu'il puisse traiter les données fournit par ces capteur afin de jouer le bon son au bon moment.   

Nous avons donc conçu plusieurs scénarios intégrant un ou plusieurs capteur afin de vous montrer comment programmer le micro-contrôleur et exploiter les capteurs associés.   
Des explications sont ajouté dans le code de chaque scénario afin de vous aider à mieux comprendre ce que fait chaque programme.


## Pré-requis à la programmation
Il est nécessaire de respecter quelques pré-requis afin de pouvoir programmer le micro-contrôleur.

1. Installer le logiciel [Arduino IDE](https://www.arduino.cc/en/software) dont l'installateur est disponible [ici](https://downloads.arduino.cc/arduino-ide/arduino-ide_2.1.0_Windows_64bit.exe).
2. Installer les pilotes logiciel pour la carte Arduino Nano v3.   
   Ces derniers s'installent automatiquement lors du lancement du logiciel _Arduino IDE_.
3. Configurer la carte sur le logiciel _Arduino IDE_ :
   - Barre des menus > Outils > Cartes > Arduino AVR Boards > Arduino nano
   - Barre des menus > Outils > Port > _COMx_
   - Barre des menus > Outils > Processeur > ATmega328P (Old bootloader)

## Ajout de son sur le module lecteur MP3
Par défaut, les modules MP3 sont livrés avec 4 courtes piste audio. On peut cependant vouloir changer ou ajouter de nouvelles pistes audio. Il suffit alors de suivre les instructions ci-dessous.

**Attention:** Le muodule MP3 ne dispose que de 4MB de mémoire pour les pistes audio.

1. Connecter le module MP3 à l'ordinateur via un câble micro-usb
2. Ouvrir l'explorateur de fichier et se rendre dans le périphérique nouvellement monté
3. Ajouter / supprimer des pistes audio

**Attention:** Le format de la piste audio doit être un **MP3** (.mp3) et le nom du fichier doit être compris entre **00001.mp3** et **00255.mp3**

La documentation du module MP3 est disponible [ici](https://github.com/smoluks/DY-SV17F/blob/master/DY-SV17F%20module%20functions%20introduction.pdf) (en anglais).

## Scénario 1 : Capteur d'inclinaison
Afin de se rapprocher au plus près du fonctionnement d'une _réelle_ boite à meuh ce scénario utilise un capteur d'inclinaison.   
Lorsque l'on retourne la Boitearire, une petite bille métallique intégrée dans le capteur vient faire contact entre les deux bornes de ce dernier. On se retrouve donc avec un interrupteur fermé, ce qui déclenche la lecture d'une piste audio.

Pour utiliser ce scénario, ouvrez le programme `scenario1_capteur_inclinaison` puis lancez le téléversement sur votre micro-contrôleur.

Ps : le capteur d'inclinaison ressemble à ça.   
![Capteur inclinaison](images/capteur_inclinaison.jpg)

## Scénario 2 : Accéléromètre
Avoir un comportement proche d'une réelle boite à meuh est intéressant, certes, mais nous pouvons faire des choses bien plus complexes avec la Boitearire !   
La carte est en effet équipée d'un module accéléromètre, un composant capable de détecter les changements d'accélération selon 3 axes et de les mesurer. Nous pouvons donc déclencher la lecture d'une piste lorsque un mouvement est réalisé et non plus seulement lorsque la carte est retournée. 

Pour utiliser ce scénario, ouvrez le programme `scenario2_accelerometre` puis lancez le téléversement sur votre micro-contrôleur.

Par défaut le code est configuré pour ne détecter que les rotation sur trois axes.  
Il est cependant possible de configurer le code pour qu'une piste soit jouée lorsqu'une accélération quelconque est appliqué à la carte.  
Pour cela, commenter la ligne suivante dans le code du scénario : 
```c
...

// Définition des constantes de paramétrage
// #define ACCEL_ROTATION_DETECT     // Activation de la lecture sur rotation de la boitearire et non sur mouvement seul
#define DELAY_MP3_RESET     100   // Temps d'activation pour réinitalisation du module MP3
...
```

Ps : l'accéléromètre ressemble à ça :  
![Capteur inclinaison](images/accelerometre.jpg)